@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.18 2003/12/25 14:48:12 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.24 2004/02/06 22:06:42 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,6 +32,7 @@
 #include "nsIDOMElement.h"
 #include "nsIDOMXULDocument.h"
 #include "nsIURI.h"
+#include "nsNetUtil.h"
 #include "nsIDOMNSDocument.h"
 #include "nsReadableUtils.h"
 #include "nsUnicharUtils.h"
@@ -145,10 +146,14 @@ nsresult EventContext::GatherTextUnder (nsIDOMNode* aNode, nsString& aResult)
 nsresult EventContext::ResolveBaseURL (nsIDocument *doc, const nsAString &relurl, nsACString &url)
 {
 	nsresult rv;
-#if MOZILLA_SNAPSHOT > 11
+#if MOZILLA_SNAPSHOT > 13
+	nsIURI *base;
+	base = doc->GetBaseURI ();
+	if (!base) return NS_ERROR_FAILURE;
+#elif MOZILLA_SNAPSHOT > 11
 	nsIURI *base;
 	base = doc->GetBaseURL ();
-	if (base == NULL) return NS_ERROR_FAILURE;
+	if (!base) return NS_ERROR_FAILURE;
 #elif MOZILLA_SNAPSHOT > 9 
 	nsCOMPtr<nsIURI> base;
 	rv = doc->GetBaseURL (getter_AddRefs(base));
@@ -165,10 +170,14 @@ nsresult EventContext::ResolveBaseURL (nsIDocument *doc, const nsAString &relurl
 nsresult EventContext::ResolveDocumentURL (nsIDocument *doc, const nsAString &relurl, nsACString &url)
 {
 	nsresult rv;
-#if MOZILLA_SNAPSHOT > 11
+#if MOZILLA_SNAPSHOT > 13
+	nsIURI *uri;
+	uri = doc->GetDocumentURI ();
+	if (!uri) return NS_ERROR_FAILURE;
+#elif MOZILLA_SNAPSHOT > 11
 	nsIURI *uri;
 	uri = doc->GetDocumentURL ();
-	if (uri == NULL) return NS_ERROR_FAILURE;
+	if (!uri) return NS_ERROR_FAILURE;
 #else
 	nsCOMPtr<nsIURI> uri;
 	rv = doc->GetDocumentURL(getter_AddRefs(uri));
@@ -179,7 +188,7 @@ nsresult EventContext::ResolveDocumentURL (nsIDocument *doc, const nsAString &re
 }
 
 nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
-					EphyEmbedEvent *info)
+					MozillaEmbedEvent *info)
 {
 	nsresult rv;
 
@@ -381,6 +390,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 				dom_elem->GetAttributeNS (nspace, localname_href, value);
 				
 				SetStringProperty ("link", value);
+				CheckLinkScheme (value);
 			}
 		}
 
@@ -424,6 +434,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 					info->context |= EMBED_CONTEXT_LINK;
 
 					SetStringProperty ("link", tmp);
+					CheckLinkScheme (tmp);
 					rv = anchor->GetHreflang (tmp);
 					if (NS_SUCCEEDED(rv))
 						SetStringProperty ("link_lang", tmp);
@@ -470,10 +481,6 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 					{
 						SetIntProperty ("link_is_smart", FALSE);
 					}
-#ifdef NOT_PORTED
-					/* Get the text of the link */
-					info->linktext = mozilla_get_link_text (node);
-#endif
 				}
 			
 			}
@@ -497,6 +504,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 						return NS_ERROR_FAILURE;
 					
 					SetStringProperty ("link", href);
+					CheckLinkScheme (href);
 				}
 			}
 			else if (tag.Equals(NS_LITERAL_STRING("textarea"),
@@ -623,7 +631,7 @@ nsresult EventContext::GetCSSBackground (nsIDOMNode *node, nsAutoString& url)
 	return NS_OK;
 }
 
-nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, EphyEmbedEvent *info)
+nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, MozillaEmbedEvent *info)
 {
 	nsresult result;
 
@@ -706,7 +714,7 @@ nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, EphyEmb
 	return NS_OK;
 }
 
-nsresult EventContext::GetKeyEventInfo (nsIDOMKeyEvent *aKeyEvent, EphyEmbedEvent *info)
+nsresult EventContext::GetKeyEventInfo (nsIDOMKeyEvent *aKeyEvent, MozillaEmbedEvent *info)
 {
 	nsresult rv;
 
@@ -794,6 +802,31 @@ nsresult EventContext::GetTargetDocument (nsIDOMDocument **domDoc)
 	return NS_OK;
 }
 
+nsresult EventContext::CheckLinkScheme (const nsAString &link)
+{
+	nsCOMPtr<nsIURI> uri;
+	NS_NewURI (getter_AddRefs (uri), link);
+	if (!uri) return NS_ERROR_FAILURE;
+
+	nsresult rv;
+	nsCAutoString scheme;
+	rv = uri->GetScheme (scheme);
+	if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
+
+	if (scheme.EqualsIgnoreCase ("http")  ||
+	    scheme.EqualsIgnoreCase ("https") ||
+	    scheme.EqualsIgnoreCase ("ftp")   ||
+	    scheme.EqualsIgnoreCase ("file")  ||
+	    scheme.EqualsIgnoreCase ("data")  ||
+	    scheme.EqualsIgnoreCase ("about") ||
+	    scheme.EqualsIgnoreCase ("gopher"))
+	{
+		SetIntProperty ("link-has-web-scheme", TRUE);
+	}
+
+	return NS_OK;
+}
+
 nsresult EventContext::SetIntProperty (const char *name, int value)
 {
 
@@ -803,9 +836,7 @@ nsresult EventContext::SetIntProperty (const char *name, int value)
 	
 	g_value_set_int (val, value);
 
-	ephy_embed_event_set_property (mEmbedEvent, 
-			     	       name,
-			     	       val);
+	mozilla_embed_event_set_property (mEmbedEvent, name, val);
 
 	return NS_OK;
 }
@@ -818,9 +849,7 @@ nsresult EventContext::SetStringProperty (const char *name, const char *value)
 	
 	g_value_set_string (val, value);
 			 
-	ephy_embed_event_set_property (mEmbedEvent, 
-			     	       name,
-			     	       val);
+	mozilla_embed_event_set_property (mEmbedEvent, name, val);
 
 	return NS_OK;
 }
