@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.59 2004/01/22 23:17:35 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.60 2004/02/12 20:18:52 chpe Exp $
  */
 
 #include "mozilla-embed.h"
@@ -1028,7 +1028,7 @@ mozilla_embed_security_change_cb (GtkMozEmbed *embed,
 {
 	EmbedSecurityLevel level;
 
-	membed->priv->request = (nsIRequest *) request;
+	membed->priv->request = static_cast<nsIRequest*>(request);
 	membed->priv->security_state = state;
 	level = mozilla_embed_security_level (membed);
 
