@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000 Nate Case 
+ *  Copyright (C) 2000 Nate Case
+ *  Copyright (C) 2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,14 +15,16 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: mozilla-notifiers.cpp,v 1.45 2004/01/25 13:51:21 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
+#include "ephy-embed-shell.h"
 #include "mozilla-notifiers.h"
 #include "eel-gconf-extensions.h"
 #include "MozRegisterComponents.h"
@@ -36,6 +39,8 @@
 #include <glib/gi18n.h>
 #include <stdlib.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtksettings.h>
+
 #include <nsCOMPtr.h>
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
@@ -133,18 +138,20 @@ static const struct
 }
 conversion_table [] =
 {
-	{ CONF_SECURITY_JAVA_ENABLED, BOOL_PREF, "security.enable_java"},
-	{ CONF_SECURITY_JAVASCRIPT_ENABLED, BOOL_PREF, "javascript.enabled"},
-	{ CONF_NETWORK_PROXY_AUTO_URL, STRING_PREF, "network.proxy.autoconfig_url"},
-	{ CONF_NETWORK_HTTP_PROXY, STRING_PREF, "network.proxy.http"},
-	{ CONF_NETWORK_FTP_PROXY, STRING_PREF, "network.proxy.ftp"},
-	{ CONF_NETWORK_SSL_PROXY, STRING_PREF, "network.proxy.ssl"},
-	{ CONF_NETWORK_HTTP_PROXY_PORT, INT_PREF, "network.proxy.http_port"},
-	{ CONF_NETWORK_FTP_PROXY_PORT, INT_PREF, "network.proxy.ftp_port"},
-	{ CONF_NETWORK_SSL_PROXY_PORT, INT_PREF, "network.proxy.ssl_port"},
+	{ CONF_SECURITY_JAVA_ENABLED, BOOL_PREF, "security.enable_java" },
+	{ CONF_SECURITY_JAVASCRIPT_ENABLED, BOOL_PREF, "javascript.enabled" },
+	{ CONF_NETWORK_PROXY_AUTO_URL, STRING_PREF, "network.proxy.autoconfig_url" },
+	{ CONF_NETWORK_HTTP_PROXY, STRING_PREF, "network.proxy.http" },
+	{ CONF_NETWORK_FTP_PROXY, STRING_PREF, "network.proxy.ftp" },
+	{ CONF_NETWORK_SSL_PROXY, STRING_PREF, "network.proxy.ssl" },
+	{ CONF_NETWORK_SOCKS_PROXY, STRING_PREF, "network.proxy.socks" },
+	{ CONF_NETWORK_HTTP_PROXY_PORT, INT_PREF, "network.proxy.http_port" },
+	{ CONF_NETWORK_FTP_PROXY_PORT, INT_PREF, "network.proxy.ftp_port" },
+	{ CONF_NETWORK_SSL_PROXY_PORT, INT_PREF, "network.proxy.ssl_port" },
+	{ CONF_NETWORK_SOCKS_PROXY_PORT, INT_PREF, "network.proxy.socks_port" },
 	{ CONF_LANGUAGE_DEFAULT_ENCODING, STRING_PREF, "intl.charset.default" },
 	{ CONF_LANGUAGE_AUTODETECT_ENCODING, STRING_PREF, "intl.charset.detector" },
-	{ CONF_RENDERING_DEFAULT_FONT, STRING_PREF, "font.default" },
+	{ CONF_BROWSE_WITH_CARET, BOOL_PREF, "accessibility.browsewithcaret" },
 
 	{ NULL, 0, NULL }
 };
@@ -794,6 +801,7 @@ mozilla_language_notifier(GConfClient *client,
 			}
 
 			g_strfreev (s);
+			g_free (sys_lang);
 		}		
 	}
 
