@@ -14,8 +14,14 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: egg-editable-toolbar.c,v 1.44 2004/02/09 14:15:13 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "egg-editable-toolbar.h"
 #include "egg-toolbars-model.h"
 
@@ -68,6 +74,8 @@ static guint egg_editable_toolbar_signals[LAST_SIGNAL] = { 0 };
 
 static GObjectClass *parent_class = NULL;
 
+#define EGG_EDITABLE_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EGG_TYPE_EDITABLE_TOOLBAR, EggEditableToolbarPrivate))
+
 struct EggEditableToolbarPrivate
 {
   GtkUIManager *merge;
@@ -174,7 +182,7 @@ find_action (EggEditableToolbar *t,
 
   l = gtk_ui_manager_get_action_groups (t->priv->merge);
 
-  g_return_val_if_fail (IS_EGG_EDITABLE_TOOLBAR (t), NULL);
+  g_return_val_if_fail (EGG_IS_EDITABLE_TOOLBAR (t), NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
   for (; l != NULL; l = l->next)
@@ -196,7 +204,7 @@ drag_data_delete_cb (GtkWidget          *widget,
 {
   int pos, toolbar_pos;
 
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (etoolbar));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (etoolbar));
 
   pos = gtk_toolbar_get_item_index (GTK_TOOLBAR (widget->parent),
 				    GTK_TOOL_ITEM (widget));
@@ -233,7 +241,7 @@ drag_data_get_cb (GtkWidget          *widget,
   GtkAction *action;
   const char *target;
 
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (etoolbar));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (etoolbar));
 
   action = GTK_ACTION (g_object_get_data (G_OBJECT (widget), "gtk-action"));
 
@@ -298,13 +306,26 @@ set_item_drag_source (GtkWidget *item,
     {
       const char *stock_id;
       GValue value = { 0, };
-                                                                                                                             
+      GdkPixbuf *pixbuf;
+
       g_value_init (&value, G_TYPE_STRING);
       g_object_get_property (G_OBJECT (action), "stock_id", &value);
-                                                                                                                             
       stock_id = g_value_get_string (&value);
-      gtk_drag_source_set_icon_stock
-	(item, stock_id ? stock_id : GTK_STOCK_DND);
+
+      if (stock_id != NULL)
+        {
+          pixbuf = gtk_widget_render_icon (item, stock_id,
+				           GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+        }
+      else
+        {
+          pixbuf = gtk_widget_render_icon (item, GTK_STOCK_DND,
+					   GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+        }
+
+      gtk_drag_source_set_icon_pixbuf (item, pixbuf);
+      g_object_unref (pixbuf);
+
       g_value_unset (&value);
     }
 }
@@ -404,8 +425,7 @@ drag_data_received_cb (GtkWidget          *widget,
 	  
   target = gtk_drag_dest_find_target (widget, context, NULL);
   type = egg_toolbars_model_get_item_type (etoolbar->priv->model, target);
-  id = egg_toolbars_model_get_item_id (etoolbar->priv->model, type,
-				       selection_data->data);
+  id = egg_toolbars_model_get_item_id (etoolbar->priv->model, type, selection_data->data);
 
   /* This function can be called for two reasons
    *
@@ -418,6 +438,13 @@ drag_data_received_cb (GtkWidget          *widget,
    *      actually add a new item to the toolbar.
    */
 
+  if (id == NULL)
+    {
+      etoolbar->priv->pending = FALSE;
+      g_free (type);
+      return;
+    }
+
   if (etoolbar->priv->pending)
     {
       etoolbar->priv->pending = FALSE;
@@ -438,11 +465,6 @@ drag_data_received_cb (GtkWidget          *widget,
 	}
       else
 	{
-	  type = egg_toolbars_model_get_item_type (etoolbar->priv->model,
-						   target);
-	  id = egg_toolbars_model_get_item_id (etoolbar->priv->model, type,
-					       selection_data->data);
-
 	  egg_toolbars_model_add_item (etoolbar->priv->model,
 				       toolbar_pos, pos, id, type);
 	}
@@ -576,9 +598,12 @@ toolbar_drag_motion_cb (GtkWidget          *widget,
       /* The handler will make sure the item is created */
       gtk_drag_get_data (widget, context, target, time);
 
-      g_assert (etoolbar->priv->dragged_item);
       g_assert (!etoolbar->priv->pending);
 
+      if (etoolbar->priv->dragged_item == NULL) {
+	return TRUE;
+      }
+
       g_object_ref (etoolbar->priv->dragged_item);
       gtk_object_sink (GTK_OBJECT (etoolbar->priv->dragged_item));
     }
@@ -883,12 +908,28 @@ static void
 egg_editable_toolbar_set_model (EggEditableToolbar *t,
 				EggToolbarsModel   *model)
 {
-  g_return_if_fail (IS_EGG_TOOLBARS_MODEL (model));
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (t));
+  g_return_if_fail (EGG_IS_TOOLBARS_MODEL (model));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (t));
 
   if (t->priv->model == model) return;
 
-  t->priv->model = model;
+  if (t->priv->model)
+    {
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (item_added_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (item_removed_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (toolbar_added_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (toolbar_removed_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (toolbar_changed_cb), t);
+
+       g_object_unref (t->priv->model);
+    }
+
+  t->priv->model = g_object_ref (model);
 
   toolbars_clean (t);
   egg_editable_toolbar_construct (t);
@@ -910,16 +951,20 @@ egg_editable_toolbar_set_merge (EggEditableToolbar *t,
 				GtkUIManager       *merge)
 {
   g_return_if_fail (GTK_IS_UI_MANAGER (merge));
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (t));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (t));
 
-  if (t->priv->merge != merge)
+  if (t->priv->merge == merge) return;
+
+  if (t->priv->merge)
     {
-      t->priv->merge = merge;
+      g_object_unref (t->priv->merge);
+    }
 
-      if (t->priv->model != NULL)
-        {
-          egg_editable_toolbar_construct (t);
-        }
+  t->priv->merge = g_object_ref (merge);
+
+  if (t->priv->model != NULL)
+    {
+      egg_editable_toolbar_construct (t);
     }
 }
 
@@ -992,14 +1037,16 @@ egg_editable_toolbar_class_init (EggEditableToolbarClass *klass)
 				   g_param_spec_object ("ToolbarsModel",
 							"ToolbarsModel",
 							"Toolbars Model",
-							EGG_TOOLBARS_MODEL_TYPE,
+							EGG_TYPE_TOOLBARS_MODEL,
 							G_PARAM_READWRITE));
+
+  g_type_class_add_private (object_class, sizeof (EggEditableToolbarPrivate));
 }
 
 static void
 egg_editable_toolbar_init (EggEditableToolbar *t)
 {
-  t->priv = g_new0 (EggEditableToolbarPrivate, 1);
+  t->priv = EGG_EDITABLE_TOOLBAR_GET_PRIVATE (t);
 
   t->priv->merge = NULL;
   t->priv->edit_mode = FALSE;
@@ -1010,15 +1057,20 @@ egg_editable_toolbar_finalize (GObject *object)
 {
   EggEditableToolbar *t = EGG_EDITABLE_TOOLBAR (object);
 
-  g_return_if_fail (object != NULL);
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (object));
-
   if (t->priv->fixed_toolbar)
     {
       g_object_unref (t->priv->fixed_toolbar);
     }
 
-  g_free (t->priv);
+  if (t->priv->merge)
+    {
+      g_object_unref (t->priv->merge);
+    }
+
+  if (t->priv->model)
+    {
+      g_object_unref (t->priv->model);
+    }
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -1027,15 +1079,10 @@ GtkWidget *
 egg_editable_toolbar_new (GtkUIManager     *merge,
 			  EggToolbarsModel *model)
 {
-  EggEditableToolbar *t;
-
-  t = EGG_EDITABLE_TOOLBAR (g_object_new (EGG_EDITABLE_TOOLBAR_TYPE,
-					  "ToolbarsModel", model,
-					  "MenuMerge", merge, NULL));
-
-  g_return_val_if_fail (t->priv != NULL, NULL);
-
-  return GTK_WIDGET (t);
+  return GTK_WIDGET (g_object_new (EGG_TYPE_EDITABLE_TOOLBAR,
+				   "ToolbarsModel", model,
+				   "MenuMerge", merge,
+				   NULL));
 }
 
 void
