@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,11 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.33 2003/11/05 22:56:16 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.37 2004/02/11 14:38:55 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <gtk/gtktoolitem.h>
@@ -293,8 +293,6 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 
 		g_list_free (node_list);
 	}
-
-	ephy_node_thaw (node);
 }
 
 static GtkWidget *
@@ -400,7 +398,6 @@ build_topics_menu (EphyTopicAction *action, EphyNode *node)
 		gtk_widget_show (bmk_menu);
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), bmk_menu);
 	}
-	ephy_node_thaw (node);
 	g_list_free (node_list);
 
 	uncategorized = ephy_bookmarks_get_not_categorized (bookmarks);
@@ -484,26 +481,6 @@ create_menu_item (GtkAction *action)
 	return menu_item;
 }
 
-static gboolean
-create_menu_proxy (GtkToolItem *item, GtkAction *action)
-{
-	GtkWidget *menu_item;
-	char *menu_id;
-
-	LOG ("create_menu_proxy item %p, action %p", item, action)
-
-	menu_item = create_menu_item (action);
-
-	menu_id = g_strdup_printf ("ephy-topic-action-%d-menu-id",
-				   EPHY_TOPIC_ACTION (action)->priv->topic_id);
-
-	gtk_tool_item_set_proxy_menu_item (item, menu_id, menu_item);
-
-	g_free (menu_id);
-
-	return TRUE;
-}
-
 static void
 connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
@@ -519,10 +496,6 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
-		g_signal_connect_object (proxy, "create_menu_proxy",
-					 G_CALLBACK (create_menu_proxy),
-					 action, 0);
-
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "toggled",
 				  G_CALLBACK (button_toggled_cb), action);
@@ -637,7 +610,10 @@ sync_topic_properties (GtkAction *action, EphyNode *bmk)
 }
 
 static void
-topic_child_changed_cb (EphyNode *node, EphyNode *child, GtkAction *action)
+topic_child_changed_cb (EphyNode *node,
+			EphyNode *child,
+			guint property_id,
+			GtkAction *action)
 {
 	gulong id;
 
