@@ -1,6 +1,7 @@
 /*
  *  Copyright (C) 2002 Jorn Baayen
  *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c,v 1.32 2003/12/07 10:23:31 chpe Exp $
+ *  $Id: pdm-dialog.c,v 1.35 2004/01/23 18:07:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,6 +27,7 @@
 #include "pdm-dialog.h"
 #include "ephy-shell.h"
 #include "ephy-cookie-manager.h"
+#include "ephy-file-helpers.h"
 #include "ephy-password-manager.h"
 #include "ephy-gui.h"
 #include "ephy-ellipsizing-label.h"
@@ -179,12 +181,9 @@ pdm_dialog_show_help (PdmDialog *pd)
 	GtkWidget *notebook, *window;
 	int id;
 
-	/* FIXME: Once we actually have documentation we
-	 * should point these at the correct links.
-	 */
 	char *help_preferences[] = {
-		"pdm",
-		"pdm"
+		"managing-cookies",
+		"managing-passwords"
 	};
 
 	window = ephy_dialog_get_control (EPHY_DIALOG (pd), properties[PROP_WINDOW].id);
@@ -787,8 +786,9 @@ pdm_dialog_init (PdmDialog *dialog)
 
 	ephy_dialog_construct (EPHY_DIALOG(dialog),
 			       properties,
-			       "epiphany.glade",
-			       "pdm_dialog");
+			       ephy_file ("epiphany.glade"),
+			       "pdm_dialog",
+			       NULL);
 
 	/**
 	 * Group all Properties and Remove buttons in the same size group to
