@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.102 2003/12/25 14:48:12 chpe Exp $
+ *  $Id: window-commands.c,v 1.111 2004/02/11 08:19:27 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,6 +31,7 @@
 #include "print-dialog.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
+#include "ephy-embed-prefs.h"
 #include "ephy-dialog.h"
 #include "ephy-bookmarks-editor.h"
 #include "ephy-history-window.h"
@@ -94,6 +95,8 @@ window_cmd_file_print_preview (GtkAction *action,
 
 	ephy_embed_print (embed, info);
 
+	ephy_print_info_free (info);
+
 	ephy_window_set_print_preview (window, TRUE);
 }
 
@@ -269,7 +272,7 @@ window_cmd_view_reload (GtkAction *action,
 	ephy_embed_activate (embed);
 
 	ephy_embed_reload (embed, force ? EMBED_RELOAD_NORMAL
-					: EMBED_RELOAD_BYPASSCACHE);
+					: EMBED_RELOAD_FORCE);
 }
 
 void
@@ -688,7 +691,7 @@ save_source_completed_cb (EphyEmbedPersist *persist)
 	dest = ephy_embed_persist_get_dest (persist);
 	g_return_if_fail (dest != NULL);
 
-	ephy_shell_delete_on_exit (ephy_shell, dest);
+	ephy_file_delete_on_exit (dest);
 
 	editor_open_uri (dest);
 }
@@ -736,9 +739,21 @@ save_temp_source (EphyEmbed *embed)
 	char *tmp, *base;
 	EphyEmbedPersist *persist;
 
-	base = g_build_filename (g_get_tmp_dir (), "viewsourceXXXXXX", NULL);
+	const char *static_temp_dir;
+
+	static_temp_dir = ephy_file_tmp_dir ();
+	if (static_temp_dir == NULL)
+	{
+		return;
+	}
+
+	base = g_build_filename (static_temp_dir, "viewsourceXXXXXX", NULL);
 	tmp = ephy_file_tmp_filename (base, "html");
 	g_free (base);
+	if (tmp == NULL)
+	{
+		return;
+	}
 
 	persist = EPHY_EMBED_PERSIST
 		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
@@ -930,11 +945,12 @@ window_cmd_help_about (GtkAction *action,
 	char *documenters[] = {
 		"Patanjali Somayaji <patanjali@codito.com>",
 		"David Bordoley <bordoley@msu.edu>",
+		"Piers Cornwell", 
 		NULL
 	};
 
 	/* Translator credits */
-	char *translator_credits = _("translator_credits");
+	char *translator_credits = _("translator-credits");
 
 	if (about != NULL)
 	{
@@ -963,11 +979,11 @@ window_cmd_help_about (GtkAction *action,
 
 	about = gnome_about_new(
 		       "Epiphany", VERSION,
-		       "Copyright \xc2\xa9 2002-2003 Marco Pesenti Gritti",
+		       "Copyright \xc2\xa9 2002-2004 Marco Pesenti Gritti",
 		       _("A GNOME browser based on Mozilla"),
 		       (const char **)authors,
 		       (const char **)documenters,
-		       strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		       strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		       logo);
 
 	if (logo != NULL)
@@ -1104,3 +1120,12 @@ window_cmd_load_location (GtkAction *action,
 	}
 }
 
+void
+window_cmd_browse_with_caret (GtkAction *action,
+			      EphyWindow *window)
+{
+	gboolean active;
+
+	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+	eel_gconf_set_boolean (CONF_BROWSE_WITH_CARET, active);
+}
